@@ -41,10 +41,9 @@ def patch_middleware_classes():
                            'django_sql_debug.middleware.SQLDebugMiddleware')
 
 
-print(USER_CONFIG)
 CONFIG = CONFIG_DEFAULTS.copy()
 CONFIG.update(USER_CONFIG)
-print(CONFIG)
+
 
 def patch_all():
     patch_middleware_classes()
